/// Core library for [AngularDart](https://webdev.dartlang.org/angular) applications.
library ngx_core;

import 'dart:async';
import 'dart:collection';
import 'dart:html' as dom;
import 'package:angular/angular.dart';
import 'package:angular_router/angular_router.dart';

part 'src/di.dart';
part 'src/directives/document_title.dart';
part 'src/directives/go_back.dart';
part 'src/pipes/encode_uri_pipe.dart';
part 'src/pipes/nl2br_pipe.dart';
part 'src/services/application.dart';
part 'src/services/configuration.dart';
part 'src/services/document_ref.dart';
part 'src/services/meta.dart';
part 'src/services/title.dart';

/// The module directives.
const List ngxDirectives = const [
  DocumentTitle,
  GoBack
];

/// The module pipes.
const List ngxPipes = const [
  EncodeUriPipe,
  Nl2brPipe
];

/// The module providers.
const List ngxProviders = const [
  const FactoryProvider(dom.HtmlDocument, documentFactory),
  const FactoryProvider(dom.Window, windowFactory),
  const ClassProvider(Application),
  const ClassProvider(Configuration),
  const ClassProvider(DocumentRef),
  const ClassProvider(Meta),
  const ClassProvider(Title)
];

/// The module instance.
const Module ngxModule = const Module(provide: ngxProviders);
